#! /usr/bin/env python
# -*- coding: utf-8 -*
# flake8: NOQA
import logging
from us import states
from .registry import DOWNLOADERS
from .age import AgeDownloader
from .education import EducationDownloader
from .foreignborn import ForeignBornDownloader
from .householdincome import (
    HouseholdIncomeDownloader,
    HouseholdIncomeLatinoDownloader,
    HouseholdIncomeWhiteDownloader,
    HouseholdIncomeBlackDownloader,
    HouseholdIncomeAsianDownloader
)
from .internet import InternetDownloader
from .medianage import MedianAgeDownloader
from .medianhouseholdincome import (
    MedianHouseholdIncomeDownloader,
    MedianHouseholdIncomeLatinoDownloader,
    MedianHouseholdIncomeWhiteDownloader,
    MedianHouseholdIncomeBlackDownloader,
    MedianHouseholdIncomeAsianDownloader
)
from .medianmonthlyhousingcosts import MedianMonthlyHousingCostsDownloader
from .mobility import (
    MobilityDownloader,
    MobilityBySexDownloader,
    MobilityWhiteDownloader,
    MobilityBlackDownloader,
    MobilityAsianDownloader,
    MobilityLatinoDownloader
)
from .population import PopulationDownloader
from .race import RaceDownloader
from .tenure import (
    TenureDownloader,
    TenureLatinoDownloader,
    TenureWhiteDownloader,
    TenureBlackDownloader,
    TenureAsianDownloader
)
from .yearstructurebuilt import YearStructureBuiltDownloader
logger = logging.getLogger(__name__)


def download_usa(*args, **kwargs):
    """
    Download all the nationwide data.
    """
    logger.debug("Downloading all datasets for all nationwide geographies")
    for klass in DOWNLOADERS:
        obj = klass(*args, **kwargs)
        logger.debug(f"Downloading nationwide {klass.PROCESSED_TABLE_NAME} datasets")
        obj.download_usa()


def download_everything(*args, **kwargs):
    """
    Download all the data.
    """
    logger.debug("Downloading all datasets for all geographies")
    for klass in DOWNLOADERS:
        obj = klass(*args, **kwargs)
        logger.debug(f"Downloading nationwide {klass.PROCESSED_TABLE_NAME} dataset")
        obj.download_usa()
        for state in states.STATES:
            logger.debug(f"Downloading tract-level {klass.PROCESSED_TABLE_NAME} data in {state.name}")
            obj.download_tracts(state.abbr)
            logger.debug(f"Downloading legislative-district-level {klass.PROCESSED_TABLE_NAME} data in {state.name}")
            obj.download_legislative_districts_upper(state.abbr)
            obj.download_legislative_districts_upper(state.abbr)


__all__ = ("DOWNLOADERS", "download_usa", "download_everything")



#! /usr/bin/env python
# -*- coding: utf-8 -*
import collections
from .base import BaseDownloader
from .registry import register_downloader


@register_downloader
class YearStructureBuiltDownloader(BaseDownloader):
    YEAR_LIST = (
        2017,
        2016,
        2015
    )
    PROCESSED_TABLE_NAME = "yearstructurebuilt"
    RAW_TABLE_NAME = 'B25034'
    RAW_FIELD_CROSSWALK = collections.OrderedDict({
        '001E': 'housing_units',
        '002E': 'built_2014_or_later',
        '003E': 'built_2010_to_2013',
        '004E': 'built_2000_to_2009',
        '005E': 'built_1990_to_1999',
        '006E': 'built_1980_to_1989',
        '007E': 'built_1970_to_1979',
        '008E': 'built_1960_to_1969',
        '009E': 'built_1950_to_1959',
        '010E': 'built_1940_to_1949',
        '011E': 'built_1929_or_earlier'
    })
